@@ -9,8 +9,8 @@ class AttachmentInline(admin.TabularInline):
 
 
 class QueueAdmin(admin.ModelAdmin):
-    list_display = ('id', 'subject', 'to_address', 'app', 'created')
-    list_filter = ('app',)
+    list_display = ('id', 'subject', 'to_address', 'deferred', 'app', 'created')
+    list_filter = ('app', 'deferred')
     search_fields = ['to_address', 'subject', 'app', 'bcc_address']
     actions = ['send_failed']
     inlines = [AttachmentInline]
